# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: logicweave.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'logicweave.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10logicweave.proto\x12\nlogicweave\"\xef\x0b\n\x0eRequestMessage\x12@\n\x15gpio_function_request\x18\x01 \x01(\x0b\x32\x1f.logicweave.GPIOFunctionRequestH\x00\x12G\n\x19\x62\x65gin_transaction_request\x18\x02 \x01(\x0b\x32\".logicweave.BeginTransationRequestH\x00\x12\x43\n\x17\x65nd_transaction_request\x18\x05 \x01(\x0b\x32 .logicweave.EndTransationRequestH\x00\x12:\n\x12gpio_write_request\x18\x03 \x01(\x0b\x32\x1c.logicweave.GPIOWriteRequestH\x00\x12\x42\n\x16usb_bootloader_request\x18\x04 \x01(\x0b\x32 .logicweave.UsbBootloaderRequestH\x00\x12\x38\n\x11gpio_read_request\x18\x06 \x01(\x0b\x32\x1b.logicweave.GPIOReadRequestH\x00\x12\x38\n\x11i2c_setup_request\x18\x0b \x01(\x0b\x32\x1b.logicweave.I2CSetupRequestH\x00\x12\x38\n\x11i2c_write_request\x18\r \x01(\x0b\x32\x1b.logicweave.I2CWriteRequestH\x00\x12\x36\n\x10i2c_read_request\x18\x0f \x01(\x0b\x32\x1a.logicweave.I2CReadRequestH\x00\x12\x38\n\x11spi_setup_request\x18\x11 \x01(\x0b\x32\x1b.logicweave.SPISetupRequestH\x00\x12\x36\n\x10spi_read_request\x18\x13 \x01(\x0b\x32\x1a.logicweave.SPIReadRequestH\x00\x12\x38\n\x11spi_write_request\x18\x15 \x01(\x0b\x32\x1b.logicweave.SPIWriteRequestH\x00\x12@\n\x15\x66irmware_info_request\x18$ \x01(\x0b\x32\x1f.logicweave.FirmwareInfoRequestH\x00\x12:\n\x12uart_setup_request\x18\x31 \x01(\x0b\x32\x1c.logicweave.UartSetupRequestH\x00\x12\x38\n\x11uart_read_request\x18\x33 \x01(\x0b\x32\x1b.logicweave.UartReadRequestH\x00\x12:\n\x12uart_write_request\x18\x35 \x01(\x0b\x32\x1c.logicweave.UartWriteRequestH\x00\x12?\n\x15gpio_pin_pull_request\x18\x37 \x01(\x0b\x32\x1e.logicweave.GpioPinPullRequestH\x00\x12\x36\n\x10\x61\x64\x63_read_request\x18\x39 \x01(\x0b\x32\x1a.logicweave.ADCReadRequestH\x00\x12J\n\x1bi2c_write_then_read_request\x18; \x01(\x0b\x32#.logicweave.I2CWriteThenReadRequestH\x00\x12\x38\n\x11pwm_setup_request\x18= \x01(\x0b\x32\x1b.logicweave.PWMSetupRequestH\x00\x12?\n\x15pwm_set_level_request\x18? \x01(\x0b\x32\x1e.logicweave.PWMSetLevelRequestH\x00\x12\x36\n\x10sleep_ms_request\x18\x41 \x01(\x0b\x32\x1a.logicweave.SleepMsRequestH\x00\x12I\n\x1agpio_read_function_request\x18\x43 \x01(\x0b\x32#.logicweave.GPIOReadFunctionRequestH\x00\x12<\n\x13stream_uart_request\x18O \x01(\x0b\x32\x1d.logicweave.StreamUartRequestH\x00\x42\x06\n\x04kind\"\x91\x0b\n\x0fResponseMessage\x12\x37\n\x1a\x62\x65gin_transaction_response\x18\x01 \x01(\x0b\x32\x11.logicweave.EmptyH\x00\x12\x33\n\x16\x65nd_transaction_respse\x18\x02 \x01(\x0b\x32\x11.logicweave.EmptyH\x00\x12\x33\n\x0e\x65rror_response\x18\n \x01(\x0b\x32\x19.logicweave.ErrorResponseH\x00\x12\x33\n\x16gpio_function_response\x18* \x01(\x0b\x32\x11.logicweave.EmptyH\x00\x12\x30\n\x13gpio_write_response\x18\x05 \x01(\x0b\x32\x11.logicweave.EmptyH\x00\x12\x34\n\x17usb_bootloader_response\x18\t \x01(\x0b\x32\x11.logicweave.EmptyH\x00\x12:\n\x12gpio_read_response\x18\x07 \x01(\x0b\x32\x1c.logicweave.GPIOReadResponseH\x00\x12/\n\x12i2c_setup_response\x18\x0c \x01(\x0b\x32\x11.logicweave.EmptyH\x00\x12/\n\x12i2c_write_response\x18\x0e \x01(\x0b\x32\x11.logicweave.EmptyH\x00\x12\x38\n\x11i2c_read_response\x18\x10 \x01(\x0b\x32\x1b.logicweave.I2CReadResponseH\x00\x12/\n\x12spi_setup_response\x18\x12 \x01(\x0b\x32\x11.logicweave.EmptyH\x00\x12\x38\n\x11spi_read_response\x18\x14 \x01(\x0b\x32\x1b.logicweave.SPIReadResponseH\x00\x12/\n\x12spi_write_response\x18\x16 \x01(\x0b\x32\x11.logicweave.EmptyH\x00\x12\x42\n\x16\x66irmware_info_response\x18% \x01(\x0b\x32 .logicweave.FirmwareInfoResponseH\x00\x12\x30\n\x13uart_setup_response\x18\x32 \x01(\x0b\x32\x11.logicweave.EmptyH\x00\x12:\n\x12uart_read_response\x18\x34 \x01(\x0b\x32\x1c.logicweave.UartReadResponseH\x00\x12\x30\n\x13uart_write_response\x18\x36 \x01(\x0b\x32\x11.logicweave.EmptyH\x00\x12\x33\n\x16gpio_pin_pull_response\x18\x38 \x01(\x0b\x32\x11.logicweave.EmptyH\x00\x12\x38\n\x11\x61\x64\x63_read_response\x18: \x01(\x0b\x32\x1b.logicweave.ADCReadResponseH\x00\x12L\n\x1ci2c_write_then_read_response\x18< \x01(\x0b\x32$.logicweave.I2CWriteThenReadResponseH\x00\x12/\n\x12pwm_setup_response\x18> \x01(\x0b\x32\x11.logicweave.EmptyH\x00\x12\x33\n\x16pwm_set_level_response\x18@ \x01(\x0b\x32\x11.logicweave.EmptyH\x00\x12.\n\x11sleep_ms_response\x18\x42 \x01(\x0b\x32\x11.logicweave.EmptyH\x00\x12K\n\x1bgpio_read_function_response\x18\x44 \x01(\x0b\x32$.logicweave.GPIOReadFunctionResponseH\x00\x12>\n\x14stream_uart_response\x18Q \x01(\x0b\x32\x1e.logicweave.StreamUartResponseH\x00\x42\x06\n\x04kind\"m\n\x11StreamUartRequest\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x11\n\tbaud_rate\x18\x02 \x01(\r\x12\x0e\n\x06tx_pin\x18\x04 \x01(\r\x12\x0e\n\x06rx_pin\x18\x05 \x01(\r\x12\x14\n\x0cinstance_num\x18\x06 \x01(\r\"\"\n\x12StreamUartResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\'\n\x16\x42\x65ginTransationRequest\x12\r\n\x05label\x18\x01 \x01(\t\"6\n\x14\x45ndTransationRequest\x12\r\n\x05label\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\"+\n\x17GPIOReadFunctionRequest\x12\x10\n\x08gpio_pin\x18\x01 \x01(\r\"F\n\x18GPIOReadFunctionResponse\x12*\n\x08\x66unction\x18\x01 \x01(\x0e\x32\x18.logicweave.GpioFunction\"#\n\x14UsbBootloaderRequest\x12\x0b\n\x03val\x18\x01 \x01(\r\"\x17\n\x05\x45mpty\x12\x0e\n\x06status\x18\x01 \x01(\r\"\x1e\n\x0b\x45\x63hoMessage\x12\x0f\n\x07message\x18\x01 \x01(\t\"#\n\x0fGPIOReadRequest\x12\x10\n\x08gpio_pin\x18\x01 \x01(\r\"n\n\x0fPWMSetupRequest\x12\x10\n\x08gpio_pin\x18\x01 \x01(\r\x12\x0c\n\x04wrap\x18\x02 \x01(\r\x12\x15\n\rclock_div_int\x18\x03 \x01(\r\x12\x16\n\x0e\x63lock_div_frac\x18\x04 \x01(\r\x12\x0c\n\x04name\x18\x05 \x01(\t\"5\n\x12PWMSetLevelRequest\x12\x10\n\x08gpio_pin\x18\x01 \x01(\r\x12\r\n\x05level\x18\x02 \x01(\r\"\"\n\x0e\x41\x44\x43ReadRequest\x12\x10\n\x08gpio_pin\x18\x01 \x01(\r\"!\n\x0f\x41\x44\x43ReadResponse\x12\x0e\n\x06sample\x18\x01 \x01(\r\"!\n\x10GPIOReadResponse\x12\r\n\x05state\x18\x01 \x01(\x08\"3\n\x10GPIOWriteRequest\x12\x10\n\x08gpio_pin\x18\x01 \x01(\r\x12\r\n\x05state\x18\x02 \x01(\x08\"~\n\x0fSPISetupRequest\x12\x10\n\x08sclk_pin\x18\x02 \x01(\r\x12\x10\n\x08mosi_pin\x18\x03 \x01(\r\x12\x10\n\x08miso_pin\x18\x04 \x01(\r\x12\x14\n\x0cinstance_num\x18\x05 \x01(\r\x12\x11\n\tbaud_rate\x18\x06 \x01(\r\x12\x0c\n\x04name\x18\x07 \x01(\t\"E\n\x0fSPIWriteRequest\x12\x14\n\x0cinstance_num\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0e\n\x06\x63s_pin\x18\x03 \x01(\r\"X\n\x0eSPIReadRequest\x12\x14\n\x0cinstance_num\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\r\x12\x0e\n\x06\x63s_pin\x18\x03 \x01(\r\x12\x12\n\nbyte_count\x18\x04 \x01(\r\"\x1f\n\x0fSPIReadResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"O\n\x12GpioPinPullRequest\x12\x10\n\x08gpio_pin\x18\x01 \x01(\r\x12\'\n\x05state\x18\x02 \x01(\x0e\x32\x18.logicweave.PinPullState\"W\n\x0fI2CSetupRequest\x12\x0f\n\x07sda_pin\x18\x01 \x01(\r\x12\x0f\n\x07scl_pin\x18\x02 \x01(\r\x12\x14\n\x0cinstance_num\x18\x03 \x01(\r\x12\x0c\n\x04name\x18\x04 \x01(\t\"M\n\x0fI2CWriteRequest\x12\x14\n\x0cinstance_num\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x16\n\x0e\x64\x65vice_address\x18\x03 \x01(\r\"R\n\x0eI2CReadRequest\x12\x14\n\x0cinstance_num\x18\x01 \x01(\r\x12\x16\n\x0e\x64\x65vice_address\x18\x02 \x01(\r\x12\x12\n\nbyte_count\x18\x03 \x01(\r\"i\n\x17I2CWriteThenReadRequest\x12\x14\n\x0cinstance_num\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x16\n\x0e\x64\x65vice_address\x18\x03 \x01(\r\x12\x12\n\nbyte_count\x18\x04 \x01(\r\"(\n\x18I2CWriteThenReadResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\x1f\n\x0fI2CReadResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"a\n\x13GPIOFunctionRequest\x12\x10\n\x08gpio_pin\x18\x01 \x01(\r\x12*\n\x08\x66unction\x18\x02 \x01(\x0e\x32\x18.logicweave.GpioFunction\x12\x0c\n\x04name\x18\x03 \x01(\t\"i\n\x10UartSetupRequest\x12\x11\n\tbaud_rate\x18\x01 \x01(\r\x12\x0e\n\x06tx_pin\x18\x02 \x01(\r\x12\x0e\n\x06rx_pin\x18\x03 \x01(\r\x12\x14\n\x0cinstance_num\x18\x04 \x01(\r\x12\x0c\n\x04name\x18\x05 \x01(\t\"J\n\x10UartWriteRequest\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x12\n\ntimeout_ms\x18\x02 \x01(\r\x12\x14\n\x0cinstance_num\x18\x03 \x01(\r\"O\n\x0fUartReadRequest\x12\x12\n\nbyte_count\x18\x01 \x01(\r\x12\x12\n\ntimeout_ms\x18\x02 \x01(\r\x12\x14\n\x0cinstance_num\x18\x03 \x01(\r\" \n\x10UartReadResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\x15\n\x13\x46irmwareInfoRequest\"b\n\x14\x46irmwareInfoResponse\x12\"\n\x06\x64\x65vice\x18\x01 \x01(\x0e\x32\x12.logicweave.Device\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x15\n\rserial_number\x18\x03 \x01(\t\"\"\n\x0eSleepMsRequest\x12\x10\n\x08sleep_ms\x18\x01 \x01(\r\" \n\rErrorResponse\x12\x0f\n\x07message\x18\x01 \x01(\t*\x85\x01\n\x0cGpioFunction\x12\x07\n\x03xip\x10\x00\x12\x08\n\x04hstx\x10\x01\x12\x07\n\x03spi\x10\x02\x12\x08\n\x04uart\x10\x03\x12\x07\n\x03i2c\x10\x04\x12\x07\n\x03pwm\x10\x05\x12\n\n\x06sio_in\x10\x06\x12\x0b\n\x07sio_out\x10\x07\x12\x07\n\x03pio\x10\x08\x12\x08\n\x04gpck\x10\t\x12\x07\n\x03usb\x10\n\x12\x08\n\x04none\x10\x0b*+\n\x0b\x42\x61nkVoltage\x12\x08\n\x04V1P8\x10\x00\x12\x08\n\x04V3P3\x10\x01\x12\x08\n\x04V5P0\x10\x02*2\n\x0cPinPullState\x12\x08\n\x04None\x10\x00\x12\n\n\x06PullUp\x10\x01\x12\x0c\n\x08PullDown\x10\x02*:\n\x06\x44\x65vice\x12\n\n\x06rp2040\x10\x00\x12\n\n\x06rp2350\x10\x01\x12\x0b\n\x07rp2350b\x10\x02\x12\x0b\n\x07lw_core\x10\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'logicweave_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GPIOFUNCTION']._serialized_start=5228
  _globals['_GPIOFUNCTION']._serialized_end=5361
  _globals['_BANKVOLTAGE']._serialized_start=5363
  _globals['_BANKVOLTAGE']._serialized_end=5406
  _globals['_PINPULLSTATE']._serialized_start=5408
  _globals['_PINPULLSTATE']._serialized_end=5458
  _globals['_DEVICE']._serialized_start=5460
  _globals['_DEVICE']._serialized_end=5518
  _globals['_REQUESTMESSAGE']._serialized_start=33
  _globals['_REQUESTMESSAGE']._serialized_end=1552
  _globals['_RESPONSEMESSAGE']._serialized_start=1555
  _globals['_RESPONSEMESSAGE']._serialized_end=2980
  _globals['_STREAMUARTREQUEST']._serialized_start=2982
  _globals['_STREAMUARTREQUEST']._serialized_end=3091
  _globals['_STREAMUARTRESPONSE']._serialized_start=3093
  _globals['_STREAMUARTRESPONSE']._serialized_end=3127
  _globals['_BEGINTRANSATIONREQUEST']._serialized_start=3129
  _globals['_BEGINTRANSATIONREQUEST']._serialized_end=3168
  _globals['_ENDTRANSATIONREQUEST']._serialized_start=3170
  _globals['_ENDTRANSATIONREQUEST']._serialized_end=3224
  _globals['_GPIOREADFUNCTIONREQUEST']._serialized_start=3226
  _globals['_GPIOREADFUNCTIONREQUEST']._serialized_end=3269
  _globals['_GPIOREADFUNCTIONRESPONSE']._serialized_start=3271
  _globals['_GPIOREADFUNCTIONRESPONSE']._serialized_end=3341
  _globals['_USBBOOTLOADERREQUEST']._serialized_start=3343
  _globals['_USBBOOTLOADERREQUEST']._serialized_end=3378
  _globals['_EMPTY']._serialized_start=3380
  _globals['_EMPTY']._serialized_end=3403
  _globals['_ECHOMESSAGE']._serialized_start=3405
  _globals['_ECHOMESSAGE']._serialized_end=3435
  _globals['_GPIOREADREQUEST']._serialized_start=3437
  _globals['_GPIOREADREQUEST']._serialized_end=3472
  _globals['_PWMSETUPREQUEST']._serialized_start=3474
  _globals['_PWMSETUPREQUEST']._serialized_end=3584
  _globals['_PWMSETLEVELREQUEST']._serialized_start=3586
  _globals['_PWMSETLEVELREQUEST']._serialized_end=3639
  _globals['_ADCREADREQUEST']._serialized_start=3641
  _globals['_ADCREADREQUEST']._serialized_end=3675
  _globals['_ADCREADRESPONSE']._serialized_start=3677
  _globals['_ADCREADRESPONSE']._serialized_end=3710
  _globals['_GPIOREADRESPONSE']._serialized_start=3712
  _globals['_GPIOREADRESPONSE']._serialized_end=3745
  _globals['_GPIOWRITEREQUEST']._serialized_start=3747
  _globals['_GPIOWRITEREQUEST']._serialized_end=3798
  _globals['_SPISETUPREQUEST']._serialized_start=3800
  _globals['_SPISETUPREQUEST']._serialized_end=3926
  _globals['_SPIWRITEREQUEST']._serialized_start=3928
  _globals['_SPIWRITEREQUEST']._serialized_end=3997
  _globals['_SPIREADREQUEST']._serialized_start=3999
  _globals['_SPIREADREQUEST']._serialized_end=4087
  _globals['_SPIREADRESPONSE']._serialized_start=4089
  _globals['_SPIREADRESPONSE']._serialized_end=4120
  _globals['_GPIOPINPULLREQUEST']._serialized_start=4122
  _globals['_GPIOPINPULLREQUEST']._serialized_end=4201
  _globals['_I2CSETUPREQUEST']._serialized_start=4203
  _globals['_I2CSETUPREQUEST']._serialized_end=4290
  _globals['_I2CWRITEREQUEST']._serialized_start=4292
  _globals['_I2CWRITEREQUEST']._serialized_end=4369
  _globals['_I2CREADREQUEST']._serialized_start=4371
  _globals['_I2CREADREQUEST']._serialized_end=4453
  _globals['_I2CWRITETHENREADREQUEST']._serialized_start=4455
  _globals['_I2CWRITETHENREADREQUEST']._serialized_end=4560
  _globals['_I2CWRITETHENREADRESPONSE']._serialized_start=4562
  _globals['_I2CWRITETHENREADRESPONSE']._serialized_end=4602
  _globals['_I2CREADRESPONSE']._serialized_start=4604
  _globals['_I2CREADRESPONSE']._serialized_end=4635
  _globals['_GPIOFUNCTIONREQUEST']._serialized_start=4637
  _globals['_GPIOFUNCTIONREQUEST']._serialized_end=4734
  _globals['_UARTSETUPREQUEST']._serialized_start=4736
  _globals['_UARTSETUPREQUEST']._serialized_end=4841
  _globals['_UARTWRITEREQUEST']._serialized_start=4843
  _globals['_UARTWRITEREQUEST']._serialized_end=4917
  _globals['_UARTREADREQUEST']._serialized_start=4919
  _globals['_UARTREADREQUEST']._serialized_end=4998
  _globals['_UARTREADRESPONSE']._serialized_start=5000
  _globals['_UARTREADRESPONSE']._serialized_end=5032
  _globals['_FIRMWAREINFOREQUEST']._serialized_start=5034
  _globals['_FIRMWAREINFOREQUEST']._serialized_end=5055
  _globals['_FIRMWAREINFORESPONSE']._serialized_start=5057
  _globals['_FIRMWAREINFORESPONSE']._serialized_end=5155
  _globals['_SLEEPMSREQUEST']._serialized_start=5157
  _globals['_SLEEPMSREQUEST']._serialized_end=5191
  _globals['_ERRORRESPONSE']._serialized_start=5193
  _globals['_ERRORRESPONSE']._serialized_end=5225
# @@protoc_insertion_point(module_scope)
